@@ -1,6 +1,17 @@
-from typing import Any, Iterable, List, Optional, Union
+from collections.abc import Iterable
+from typing import Any, Optional, Union
+
+from moto.core.exceptions import RESTError, ServiceException
+
+
+class EC2Error(ServiceException):
+    pass
+
+
+class DryRunClientError(EC2Error):
+    code = "DryRunOperation"
+    message = "Request would have succeeded, but DryRun flag is set."
 
-from moto.core.exceptions import RESTError
 
 # EC2 has a custom root-tag - <Response> vs <ErrorResponse>
 # `terraform destroy` will complain if the roottag is incorrect
@@ -320,7 +331,7 @@ class InvalidInstanceTypeError(EC2ClientError):
 
 
 class InvalidAMIIdError(EC2ClientError):
-    def __init__(self, ami_id: Union[List[str], str]):
+    def __init__(self, ami_id: Union[list[str], str]):
         super().__init__(
             "InvalidAMIID.NotFound",
             f"The image id '[{ami_id}]' does not exist",
@@ -344,7 +355,7 @@ class InvalidAMIAttributeItemValueError(EC2ClientError):
 
 
 class MalformedAMIIdError(EC2ClientError):
-    def __init__(self, ami_id: List[str]):
+    def __init__(self, ami_id: list[str]):
         super().__init__(
             "InvalidAMIID.Malformed", f'Invalid id: "{ami_id}" (expecting "ami-...")'
         )
@@ -670,7 +681,7 @@ class AvailabilityZoneNotFromRegionError(EC2ClientError):
 
 
 class NetworkAclEntryAlreadyExistsError(EC2ClientError):
-    def __init__(self, rule_number: str):
+    def __init__(self, rule_number: int):
         super().__init__(
             "NetworkAclEntryAlreadyExists",
             f"The network acl entry identified by {rule_number} already exists.",
@@ -902,3 +913,11 @@ class AuthFailureRestricted(RESTError):
             "AuthFailure",
             "Unauthorized attempt to access restricted resource",
         )
+
+
+class InvalidUserDataError(EC2ClientError):
+    def __init__(self, message: str):
+        super().__init__(
+            "InvalidUserData.Malformed",
+            message,
+        )
